import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ChainService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get chain details
     * Get details about a chain.
     * @param chain Chain name or id
     * @returns any Default Response
     * @throws ApiError
     */
    get(chain: string): CancelablePromise<{
        result: {
            /**
             * Chain name
             */
            name: string;
            /**
             * Chain name
             */
            chain: string;
            rpc: Array<string>;
            nativeCurrency: {
                /**
                 * Native currency name
                 */
                name: string;
                /**
                 * Native currency symbol
                 */
                symbol: string;
                /**
                 * Native currency decimals
                 */
                decimals: number;
            };
            /**
             * Chain short name
             */
            shortName: string;
            /**
             * Chain ID
             */
            chainId: number;
            /**
             * Is testnet
             */
            testnet: boolean;
            /**
             * Chain slug
             */
            slug: string;
        };
    }>;
    /**
     * Get all chain details
     * Get details about all supported chains.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(): CancelablePromise<{
        result: Array<{
            /**
             * Chain name
             */
            name: string;
            /**
             * Chain name
             */
            chain: string;
            rpc: Array<string>;
            nativeCurrency: {
                /**
                 * Native currency name
                 */
                name: string;
                /**
                 * Native currency symbol
                 */
                symbol: string;
                /**
                 * Native currency decimals
                 */
                decimals: number;
            };
            /**
             * Chain short name
             */
            shortName: string;
            /**
             * Chain ID
             */
            chainId: number;
            /**
             * Is testnet
             */
            testnet: boolean;
            /**
             * Chain slug
             */
            slug: string;
        }>;
    }>;
}
