import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ConfigurationService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get wallets configuration
     * Get the engine configuration for wallets
     * @returns any Default Response
     * @throws ApiError
     */
    getWalletsConfiguration(): CancelablePromise<{
        result: ({
            type: 'local';
        } | {
            type: 'aws-kms';
            awsAccessKeyId: string;
            awsRegion: string;
        } | {
            type: 'gcp-kms';
            gcpApplicationProjectId: string;
            gcpKmsLocationId: string;
            gcpKmsKeyRingId: string;
            gcpApplicationCredentialEmail: string;
        });
    }>;
    /**
     * Update wallets configuration
     * Update the engine configuration for wallets
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateWalletsConfiguration(requestBody?: ({
        type: 'local';
    } | {
        type: 'aws-kms';
        awsAccessKeyId: string;
        awsSecretAccessKey: string;
        awsRegion: string;
    } | {
        type: 'gcp-kms';
        gcpApplicationProjectId: string;
        gcpKmsLocationId: string;
        gcpKmsKeyRingId: string;
        gcpApplicationCredentialEmail: string;
        gcpApplicationCredentialPrivateKey: string;
    })): CancelablePromise<{
        result: ({
            type: 'local';
        } | {
            type: 'aws-kms';
            awsAccessKeyId: string;
            awsRegion: string;
        } | {
            type: 'gcp-kms';
            gcpApplicationProjectId: string;
            gcpKmsLocationId: string;
            gcpKmsKeyRingId: string;
            gcpApplicationCredentialEmail: string;
        });
    }>;
    /**
     * Get chain overrides configuration
     * Get the engine configuration for chain overrides
     * @returns any Default Response
     * @throws ApiError
     */
    getChainsConfiguration(): CancelablePromise<{
        result: (string | null);
    }>;
    /**
     * Update chain overrides configuration
     * Update the engine configuration for chain overrides
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateChainsConfiguration(requestBody: {
        chainOverrides: Array<{
            name: string;
            chain: string;
            rpc: Array<string>;
            nativeCurrency: {
                name: string;
                symbol: string;
                decimals: number;
            };
            chainId: number;
            slug: string;
        }>;
    }): CancelablePromise<{
        result: (string | null);
    }>;
    /**
     * Get transaction processing configuration
     * Get the engine configuration for processing transactions
     * @returns any Default Response
     * @throws ApiError
     */
    getTransactionConfiguration(): CancelablePromise<{
        result: {
            minTxsToProcess: number;
            maxTxsToProcess: number;
            minedTxListenerCronSchedule: (string | null);
            maxTxsToUpdate: number;
            retryTxListenerCronSchedule: (string | null);
            minEllapsedBlocksBeforeRetry: number;
            maxFeePerGasForRetries: string;
            maxPriorityFeePerGasForRetries: string;
            maxRetriesPerTx: number;
        };
    }>;
    /**
     * Update transaction processing configuration
     * Update the engine configuration for processing transactions
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateTransactionConfiguration(requestBody?: {
        minTxsToProcess?: number;
        maxTxsToProcess?: number;
        minedTxListenerCronSchedule?: (string | null);
        maxTxsToUpdate?: number;
        retryTxListenerCronSchedule?: (string | null);
        minEllapsedBlocksBeforeRetry?: number;
        maxFeePerGasForRetries?: string;
        maxPriorityFeePerGasForRetries?: string;
        maxRetriesPerTx?: number;
    }): CancelablePromise<{
        result: {
            minTxsToProcess: number;
            maxTxsToProcess: number;
            minedTxListenerCronSchedule: (string | null);
            maxTxsToUpdate: number;
            retryTxListenerCronSchedule: (string | null);
            minEllapsedBlocksBeforeRetry: number;
            maxFeePerGasForRetries: string;
            maxPriorityFeePerGasForRetries: string;
            maxRetriesPerTx: number;
        };
    }>;
    /**
     * Get auth configuration
     * Get the engine configuration for auth
     * @returns any Default Response
     * @throws ApiError
     */
    getAuthConfiguration(): CancelablePromise<{
        result: {
            domain: string;
        };
    }>;
    /**
     * Update auth configuration
     * Update the engine configuration for auth
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateAuthConfiguration(requestBody: {
        domain: string;
    }): CancelablePromise<{
        result: {
            domain: string;
        };
    }>;
    /**
     * Get wallet-balance configuration
     * Get wallet-balance configuration
     * @returns any Default Response
     * @throws ApiError
     */
    getBackendWalletBalanceConfiguration(): CancelablePromise<{
        result: {
            /**
             * Minimum wallet balance in wei
             */
            minWalletBalance: string;
        };
    }>;
    /**
     * Update backend wallet balance configuration
     * Update backend wallet balance configuration
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateBackendWalletBalanceConfiguration(requestBody?: {
        /**
         * Minimum wallet balance in wei
         */
        minWalletBalance?: string;
    }): CancelablePromise<{
        result: {
            /**
             * Minimum wallet balance in wei
             */
            minWalletBalance: string;
        };
    }>;
}
