import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractRolesService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get wallets for role
     * Get all wallets with a specific role for a contract.
     * @param role The role to list wallet members
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getRole(role: string, chain: string, contractAddress: string): CancelablePromise<{
        result: Array<string>;
    }>;
    /**
     * Get wallets for all roles
     * Get all wallets in each role for a contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            admin: Array<string>;
            transfer: Array<string>;
            minter: Array<string>;
            pauser: Array<string>;
            lister: Array<string>;
            asset: Array<string>;
            unwrap: Array<string>;
            factory: Array<string>;
            signer: Array<string>;
        };
    }>;
    /**
     * Grant role
     * Grant a role to a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    grant(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The role to grant
         */
        role: string;
        /**
         * The address to grant the role to
         */
        address: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Revoke role
     * Revoke a role from a specific wallet.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    revoke(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The role to revoke
         */
        role: string;
        /**
         * The address to revoke the role from
         */
        address: string;
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
