import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Read from contract
     * Call a read function on a contract.
     * @param functionName Name of the function to call on Contract
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param args Arguments for the function. Comma Separated
     * @returns any Default Response
     * @throws ApiError
     */
    read(functionName: string, chain: string, contractAddress: string, args?: string): CancelablePromise<{
        result?: string;
    }>;
    /**
     * Write to contract
     * Call a write function on a contract.
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    write(chain: string, contractAddress: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Name of the function to call on Contract
         */
        functionName: string;
        args: Array<string>;
        txOverrides?: {
            /**
             * Native Currency Value
             */
            value?: string;
        };
    }, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
