import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class PermissionsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all permissions
     * Get all users with their corresponding permissions
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(): CancelablePromise<{
        result: Array<{
            walletAddress: string;
            permissions: string;
            label: (string | null);
        }>;
    }>;
    /**
     * Grant permissions to user
     * Grant permissions to a user
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    grant(requestBody: {
        walletAddress: string;
        permissions: ('ADMIN' | 'OWNER');
        label?: string;
    }): CancelablePromise<{
        result: {
            success: boolean;
        };
    }>;
    /**
     * Revoke permissions from user
     * Revoke a user's permissions
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    revoke(requestBody: {
        walletAddress: string;
    }): CancelablePromise<{
        result: {
            success: boolean;
        };
    }>;
}
