import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class TransactionService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get transaction status
     * Get the status for a transaction request.
     * @param queueId Transaction queue ID
     * @returns any Default Response
     * @throws ApiError
     */
    status(queueId: string): CancelablePromise<{
        result: {
            queueId: (string | null);
            chainId: (string | null);
            fromAddress: (string | null);
            toAddress: (string | null);
            data: (string | null);
            extension: (string | null);
            value: (string | null);
            nonce: (number | null);
            gasLimit: (string | null);
            gasPrice: (string | null);
            maxFeePerGas: (string | null);
            maxPriorityFeePerGas: (string | null);
            transactionType: (number | null);
            transactionHash: (string | null);
            queuedAt: (string | null);
            processedAt: (string | null);
            sentAt: (string | null);
            minedAt: (string | null);
            cancelledAt: (string | null);
            deployedContractAddress: (string | null);
            deployedContractType: (string | null);
            errorMessage: (string | null);
            sentAtBlockNumber: (number | null);
            blockNumber: (number | null);
            status: (string | null);
            /**
             * Number of times the transaction was retried.
             */
            retryCount: number;
            retryGasValues: (boolean | null);
            retryMaxFeePerGas: (string | null);
            retryMaxPriorityFeePerGas: (string | null);
            signerAddress: (string | null);
            accountAddress: (string | null);
            target: (string | null);
            sender: (string | null);
            initCode: (string | null);
            callData: (string | null);
            callGasLimit: (string | null);
            verificationGasLimit: (string | null);
            preVerificationGas: (string | null);
            paymasterAndData: (string | null);
            userOpHash: (string | null);
            functionName: (string | null);
            functionArgs: (string | null);
        };
    }>;
    /**
     * Get all transactions
     * Get all transaction requests.
     * @param page This parameter allows the user to specify the page number for pagination purposes
     * @param limit This parameter defines the maximum number of transaction request data to return per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(page?: string, limit?: string): CancelablePromise<{
        result: {
            transactions: Array<{
                queueId: (string | null);
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                processedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                status: (string | null);
                /**
                 * Number of times the transaction was retried.
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
            }>;
            totalCount: number;
        };
    }>;
    /**
     * Get all deployment transactions
     * Get all transaction requests to deploy contracts.
     * @param page This parameter allows the user to specify the page number for pagination purposes
     * @param limit This parameter defines the maximum number of transaction request data to return per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAllDeployedContracts(page?: string, limit?: string): CancelablePromise<{
        result: {
            transactions: Array<{
                queueId: (string | null);
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                processedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                status: (string | null);
                /**
                 * Number of times the transaction was retried.
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
            }>;
            totalCount: number;
        };
    }>;
    /**
     * Retry transaction
     * Retry a transaction with updated gas settings.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    retry(requestBody: {
        /**
         * Transaction queue ID
         */
        queueId: string;
        maxFeePerGas: string;
        maxPriorityFeePerGas: string;
    }): CancelablePromise<{
        result: {
            message: string;
            status: string;
        };
    }>;
    /**
     * Cancel transaction
     * Attempt to cancel a transaction by sending a null transaction with a higher gas setting. This transaction is not guaranteed to be cancelled.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    cancel(requestBody: {
        /**
         * Transaction queue ID
         */
        queueId: string;
    }): CancelablePromise<{
        result: {
            /**
             * Transaction queue ID
             */
            queueId: string;
            /**
             * Response status
             */
            status: string;
            /**
             * Response message
             */
            message: string;
            /**
             * Transaction hash of the on-chain cancel transaction
             */
            transactionHash?: string;
        };
    }>;
}
